<link href="../markdown.css" rel="stylesheet"></link>

<title>13.4. Definitions and classification</title>

<script type="text/javascript" src="https://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS_HTML">
    MathJax.Hub.Config({
        tex2jax: {
            inlineMath: [ ['$','$'], ["\\(","\\)"] ],
            displayMath: [ ['$$','$$'], ["\\[","\\]"] ],},
        TeX: {equationNumbers: {
            autoNumber: "AMS"
          },Augment: {  Definitions: {
           macros: {
             overbracket:  ['UnderOver','23B4',1],
             underbracket: ['UnderOver','23B5',1],
           }
         }}},
    });
</script>

$\renewcommand{\Re}{\operatorname{Re}}$
$\renewcommand{\Im}{\operatorname{Im}}$
$\newcommand{\erf}{\operatorname{erf}}$
$\newcommand{\dag}{\dagger}$
$\newcommand{\const}{\mathrm{const}}$

##13.4. About spectrum

> 1. [Definitions and classification](#sect-13.4.1)
> 2. [Spectrum: examples](#sect-13.4.2)
> 3. [Spectrum: explanations](#sect-13.4.3)


###<span id="sect-13.4.1"></span>Definitions and classification
------------------


####<span id="sect-13.4.1.1"></span>Definitions

Let $\mathsf{H}$ be a Hilbert space (see [Definition 4.3.3](../S4.3.html#definition-4.3.3)).

**<span id="definition-13.4.1"></span>Definition 1.**
Linear operator $L:\mathsf{H}\to\mathsf{H}$ is *bounded* if
\begin{equation}
\\| Lu\\|\le M\\|u\\|\qquad \forall u\in \mathsf{H};
\label{eq-13.4.1}
\end{equation}
the smallest constant $M$ for which it holds is called *operator norm* of $L$ and denoted $\\|L\\|$.

**<span id="definition-13.4.2"></span>Definition 2.**
Let $L:\mathsf{H}\to\mathsf{H}$ be a bounded linear operator.

1. Adjoint operator $L^\*$ is defined as
\begin{equation}
(Lu, v)= (u,L^\*v) \qquad \forall u,v\in \mathsf{H};
\label{eq-13.4.2}
\end{equation}
2. Operator $L$ is *self-adjoint* if $L^*=L$.


However one needs to consider also unbounded operators. Such operators not only fail (\ref{eq-13.4.1}) but they are not defined everywhere.

**<span id="definition-13.4.3"></span>Definition 3.**
Consider a linear operator $L:D(L)\to \mathsf{H}$ where $D(L)$ is a linear subset in $\mathsf{H}$ (i.e. it is a linear subspace but we do not call it this way because it is not closed) which is *dense* in $\mathsf{H}$ (i.e. for each $u\in \mathsf{H}$ there exists a sequence $u\_n \in D(L)$ converging to $u$ in $\mathsf{H}$). Then

1. Operator $L$ is *closed* if $u\_n\to u$,  $Lu\_n\to f$ imply that $u\in D(L)$ and $Lu=f$;
2. Operator $L$ is *symmetric* if \begin{equation}
(Lu, v)= (u,L v) \qquad \forall u,v\in D(L);
\label{eq-13.4.3}
\end{equation}
3. Symmetric operator $L$ is *self-adjoint* if $(L\pm i)^{-1}:\mathsf{H}\to D(L)$ exist: $(L\pm i)(L\pm i)^{-1}=I$,  $(L\pm i)^{-1}(L\pm i)=I$ (identical operator)

**<span id="remark-13.4.1"></span>Remark 1.**

1. For bounded operators "symmetric" equals "self-adjoint";
2. Not so for unbounded operators. F.e. $Lu=-u''$ on $(0,l)$ with
$D(L)=\\{u(0)=u'(0)=u(l)=u'(l)=0\\}$ is symmetric but not self-adjoint;
3. Self-adjoint operators have many properties which symmetric but not self-adjoint operators do not have;
4. In Quantum Mechanics *observables* are self-adjoin operators.


**<span id="thm-13.4.1"></span>Theorem 1.**
The following statements are equivalent:

1. $L$ is self-adjoint;
2. $L$ generates unitary group $e^{itL}$ ($t\in \mathbb{R}$:
$\\| e^{itL} u\\|=\\|u\\|$,  $e^{i(t\_1+t\_2)L}= e^{it\_1L}e^{it\_2L}$,
$u\in D(L)\implies e^{itL}u\in D(L)$,
$\frac{d\ }{dt}e^{itL} u= L e^{itL}u$ for all $u\in D(L)$ (and conversely, if $e^{itL}u$ is differentiable by $t$ then $u\in D(L)$;
3. Exist spectral projectors -- operators $\theta (\tau -L)$ ($\theta(\tau)=0$ as $\tau\le 0$ and $\theta(\tau)=1$ as $\tau>0$) such that $\theta(\tau -L)$ are orthogonal projectors, $\theta (\tau\_1-L)\theta (\tau\_2-L)=\theta (\tau-L)$ with $\tau=\min (\tau\_1,\tau\_2)$, $\theta (\tau-L)u\to 0$ as
$\tau\to -\infty$;  $\theta (\tau-L)u\to u$ as  $\tau\to +\infty$;
$\theta (\tau-L)u\to \theta (\tau^\*-L)$ as
$\tau\to \tau^\*-0$ and
\begin{equation}
f(L)=\int f(\tau)d\_\tau \theta (\tau-L)
\label{eq-13.4.4}
\end{equation}


**<span id="definition-13.4.4"></span>Definition 4.**
Let us consider operator $L$ (bounded or unbounded). Then

1. $z\in \mathbb{C}$ belongs to the *resolvent set* of $L$ if $(L-z)^{-1}: \mathsf{H}\to D(L)$ exists and is a bounded operator: $(L-z)^{-1}(L-z)=I$, $(L-z)(L-z)^{-1}=I$.
2. $z\in \mathbb{C}$ belongs to the *spectrum* of $L$  if it does not belong to its resolvent set. We denote spectrum of $L$ as $\sigma  (L)$.


**<span id="remark-13.4.2"></span>Remark 2.**

1. Resolvent set is always open (and spectrum is always closed) subset of $\mathbb{C}$;
2. If $L$ is self-adjoint then $\sigma  (L)\subset \mathbb{R}$;
3. If $L$ is bounded then $\sigma  (L)$ is a bounded set.


####<span id="sect-13.4.1.2"></span>Classification

*Not all points of the spectrum are born equal!* From now on we consider only self-adjoint operators.

**<span id="definition-13.4.5"></span>Definition 5.**

1. $z$ is an *eigenvalue* if there exists $u\ne 0$ s.t. $(A-z)u=0$. Then $u$ is called *eigenvector* (or *eigenfunction* depending on context) and $\\{u:\, (A-z)u=0\\}$ is an *eigenspace* (corresponding to eigenvalue $z$). The dimension of the eigenspace is called a *multiplicity* of $z$. Eigenvalues of multiplicity $1$ are *simple*, eigenvalues of multiplicity $2$ are *double*, ... but there could be eignvalues of infinite multiplicity!
2. The set of all eigenvalues is called *pure point spectrum*;
3. Eigenvalues of the finite multiplicity which are isolated from the rest of the spectrum form a *discrete spectrum*; the rest of the spectrum is called *essential spectrum*.

**<span id="definition-13.4.6"></span>Definition 6.</a>**
$z\in \mathbb{C}$ belongs to *continuous spectrum* if $z$ is not an eigenvalue and inverse operator $(L-z)^{-1}$ exists but is not a bounded operator (so its domain $D((L-z)^{-1}$ is dense).

**<span id="remark-13.4.3"></span>Remark 3.**
Continuous spectrum could be classified as well. The difference between *absolutely continuous* and *singular continuous* spectra will be illustrated but one can define also multiplicity of continuous spectrum as well. However  one needs a *Spectral Theorem* to deal with these issues properly.


###<span id="sect-13.4.2"></span>Spectrum: examples

**<span id="example-13.4.1"></span>Example 1.**
Schrödinger operator
\begin{equation}
L=-\frac{1}{2}\Delta + V(x)
\label{eq-13.4.5}
\end{equation}
with potential $V(x)\to +\infty$ as $|x|\to \infty$ has a discrete spectrum: its eignevalues $E\_n\to +\infty$ have finite multiplicities. In dimension $d=1$ all these eigenvalues are simple, not necessarily so as $d\ge 2$.

**<span id="example-13.4.2"></span>Example 2.**
Consider Laplacian on 2-dimensional sphere which appears after separation of variables for Laplacian in $\mathbb{R}^3$ in spherical coordinates in [Subsection 6.3.2](../Chaper6/S6.3.html#sect-6.3.2).
Then $-\Delta$ has a spectrum $\\{E\_n= n(n+1): n=0,1,\ldots\\}$; $E\_n$ is an eigenvalue of multiplicity $(2n+1)$. Corresponding eigenfunctions are *spherical harmonics*. See [Definition 8.1.1](../Chapter8/S8.1.html#definition-8.1.1).

**<span id="example-13.4.3"></span>Example 3.**
Schrödinger operator in 2D with a constant magnetic and no electric field
\begin{equation}
L=\frac{1}{2} (-i\partial\_x -\frac{1}{2}B y)^2 +
\frac{1}{2} (-i\partial_y +\frac{1}{2}B y)^2
\label{eq-13.4.6}
\end{equation}
with $B>0$ (or $B<0$) has a pure point spectrum. Eigenvalues
$E\_n = |B|(n+\frac{1}{2})$, $n=0,1,2,\ldots$ have infinite multiplicity   and are called *Landau levels.*

**<span id="example-13.4.4"></span>Example 4.**
"Free" particle Schrödinger operator  $L=-\frac{1}{2}\Delta$ in $\mathbb{R}^d$ has a continuous spectrum $[0,+\infty)$.


**<span id="example-13.4.5"></span>Example 5.**
Schrödinger operator (\ref{eq-13.4.5}) with potential $V(x)\to 0$ as $|x|\to \infty$ has a continuous spectrum $[0,+\infty)$ but it can have a finite or infinite number of negative eignvalues $E\_n<0$.

1. If $|V(x)|\le M(|x|+1)^{-m}$, $m>2$ the number of eigenvalues is finite.
2. For *Coulomb potential* $V(x)=-Z|x|^{-1}$ ($Z>0$) $E\_n=-\frac{Z^2}{4n^2}$ of multiplicity $n^2$, $n=1,2,\ldots$.

**<span id="example-13.4.6"></span>Example 6.**
Free particle *Dirac operator*
\begin{equation}
L=\sum \_{j=1}^3 \gamma^j (-i\partial\_{x\_j}) + \gamma^0 m, \qquad m>0
\label{eq-13.4.7}
\end{equation}
(where $\gamma^j$ are  [*Dirac matrices*](http://en.wikipedia.org/wiki/Gamma_matrices) has a continuous spectrum $(-\infty,-m]\cup [m,\infty)$.

Perturbing it by a potential $V(x)$, $V(x)\to 0$ as $|x|\to \infty$
\begin{equation}
L=\sum \_{j=1}^3 \gamma^j (-i\partial\_{x\_j}) + m\gamma^0  +V(x) I, \qquad m>0
\label{eq-13.4.8}
\end{equation}
can add a finite or infinite number of eigenvalues in *spectral gap* $(-m,m)$. They can accumulate only to the borders of the spectral gap.

**<span id="example-13.4.7"></span>Example 7.**
Perturbing [Example 3](#example-13.4.3) by a  potential $V(x)$, $V(x)\to 0$ as $|x|\to \infty$
\begin{equation}
L=\frac{1}{2} (-i\partial\_x -\frac{1}{2}B y)^2 +
\frac{1}{2} (-i\partial_y +\frac{1}{2}B y)^2+V(x)
\label{eq-13.4.9}
\end{equation}
breaks Landau levels into sequences of eigenvalues $E\_{n,k}$, $n=0,1,\ldots$, $k=1,2,\ldots$, $E\_{n,k}\to E\_n= |B|(n+\frac{1}{2})$ as $k\to \infty$.

**<span id="example-13.4.8"></span>Example 8.**
Consider Schrödinger operator (\ref{eq-13.4.5}) with periodic potential in $\mathbb{R}^d$: $V(x+a)=V(x)$ for all $a\in \Gamma$ where $\Gamma$ is a *lattice of periods*, see [Definition 4.B.1](../Chapter4/S4.B.html#definition-4.B.1). Then $L$ has a *band spectrum*.

Namely on the  *elementary cell* [Definition 4.B.3](../Chapter4/S4.B.html#definition-4.B.3) $\Omega$ consider operator $L(k)$ where $k\in \Omega^\*$ is a *quasimomentum*; $L(k)$ is given by the same formula as $L$ but s defined on functions which are *quasiperiodic with quasimomentum* $k$. Its spectrum is discrete:
$\sigma (L(k))=\\{E\_n (k): n=1,2,\ldots\\}$.

Then spectrum $\sigma (L)$ consists of *spectral bands*
\begin{gather}
\sigma\_n:=[\min \_{k\in \Omega^\*} E\_n(k) ,\max \_{k\in \Omega^\*} E\_n(k)]: \label{eq-13.4.10}\\\\
\sigma(L) =\bigcup_{n=1}^\infty \sigma\_n;
\label{eq-13.4.11}
\end{gather}
these spectral bands can overlap. The spectrum $\sigma(L)$ is continuos.

1. As dimension $d=1$ we can do better than this: $E\_n(k)$ are increasing (decreasing) functions of $k$ on $(0,\pi/a)$ (where $a$ is the period) as $n$ is odd (respectively even) and \begin{equation}E\_n^\*:=\max \_{k\in [0,\pi/a]} E\_n(k)\le E\_{(n+1)\*}:=\min \_{k\in [0,\pi/a]} E\_{n+1}(k)\label{eq-13.4.12}\end{equation} and for *generic potential* $V(x)$ all inequalities are strict and all *all spectral gaps* $(E\_n^\*,E_{(n+1\)\*})$ are open.
2. As dimension $d\ge 2$ only finite number of spectral gaps could be open.
3. Perturbation of such operator $L$ by another potential $W(x)$, $W(x)\to 0$ as $|x|\to \infty$  could can add a finite or infinite number of eigenvalues in *spectral gaps*. They can accumulate only to the borders of the spectral gaps.

**<span id="example-13.4.9"></span>Example 9.**
In the space $\ell^2(\mathbb{Z})$ (which is the space of sequences $u\_n$, $n=\ldots, -2,-1,0, 1,2,\ldots$ such that $\\|u\\|^2:=\sum\_{n=-\infty} ^{\infty}|u\_n|^2<\infty$) consider [*almost Mathieu operator*](http://en.wikipedia.org/wiki/Almost_Mathieu_operator) (which appears in the study of [*quantum Hall effect*](http://en.wikipedia.org/wiki/Quantum_Hall_effect)).
\begin{equation}
(Lu)\_n =u\_{n+1}+u\_{n-1}+2\lambda \cos (2\pi (\theta +n\alpha))
\label{eq-13.4.13}
\end{equation}
with $|\lambda|= 1$. Assume that $\alpha$ is a *Diophantine number* (which means it is an irrational number which cannot be approximated well by rational numbers; almost all irrational numbers (including all algebraic like $\sqrt{2}$) are Diophantine).

Then the spectrum $\sigma(L)$  is continuous (no eigenvalues!) but it is *singular continuous*: for any $\varepsilon>0$ it can be covered by the infinite sequence of segments of the total length $<\varepsilon$. As an example of such set see [*Cantor set*](http://en.wikipedia.org/wiki/Cantor_set).



**<span id="remark-13.4.4"></span>Remark 4.**

1. [Example 8](#example-13.4.8) was completely investigated only in the end of the 20-th century.
2. [Example 9](#example-13.4.9) was completely investigated only in the 21-st century.


###<span id="sect-13.4.3"></span>Spectrum: explanations

####<span id="sect-13.4.3.1"></span>Landau levels

Consider [Example 3](#example-13.4.3):
Schrödinger operator in 2D with a constant magnetic and no electric field
\begin{equation}
L=\frac{1}{2} (-i\partial\_x -\frac{1}{2}B y)^2 +
\frac{1}{2} (-i\partial\_y +\frac{1}{2}B y)^2
\label{eq-13.4.14}
\end{equation}
with $B>0$ (or $B<0$) has a pure point spectrum. For simplicity assume that $B>0$. We apply a *gauge transformation* which for Schrödinger operator means multiplying it from the left and right by $e^{i\hbar^{-1} \phi (x)}$ and $e^{-i\hbar^{-1} \phi (x)}$ respectively with a real-valued $\phi$ (which is an unitary transformation) and replaces $-i\hbar\nabla$ by $-i\hbar\nabla - (\nabla\phi)$ (which is equivalent to changing vector potential $\mathbf{A}(x)$ by $\nabla \phi$ which in turn does not change $\nabla \times \mathbf{A}$. Taking $\hbar=1$ and $\phi= \frac{1}{2}B xy$ we arrive to
\begin{equation\*}
L'=\frac{1}{2} (-i\partial\_x -B y)^2 +
\frac{1}{2} (-i\partial\_y )^2;
\end{equation\*}
then making Fourier transform by $x\mapsto \xi$ we get
\begin{equation\*}
L''=\frac{1}{2} (-\xi -B y)^2 +
\frac{1}{2} (-i\partial_y )^2;
\end{equation\*}
and plugging $y=B^{-\frac{1}{2}} (y\_{\textsf{new}} -B^{-1}\xi)$ we get
\begin{equation\*}
\frac{1}{2} B (-\partial\_y^2 +y^2)
\end{equation\*}
which is a harmonic oscillator multiplied by $B$ and in virtue of [Section 4.C](./Chapter4/S4.C.html) its spectrum consists of eigenvalues
$E\_n = |B|(n+\frac{1}{2})$, $n=0,1,2,\ldots$ which  are called *Landau levels.*

However there is a "hidden variable" $\xi$, so eigenfunctions Hermite functions of $y$ but multiplied by arbitrary functions $C(\xi)$ rather than by constants which implies that these eigenvalues have constant multiplicities.

####<span id="sect-13.4.3.2"></span>Band spectrum

Consider [Example 8](#example-13.4.8):  Schrödinger operator  with periodic potential in $\mathbb{R}^d$: $V(x+a)=V(x)$ for all $a\in \Gamma$ where $\Gamma$ is a lattice of periods.

Let us decompose function $u(\mathbf{x})$ into $n$-dimensional Fourier integral
\begin{equation\*}
u(x)= \iiint \_{\mathbb{R}^n} e^{i \mathbf{k}\cdot \mathbf{x}} \hat{u}(\mathbf{k})\,d^n\mathbf{k},
\end{equation\*}
then replace this integral by a sum of integrals over dual elementary cell $\Omega^\*$ shifted by $\mathbf{n}\in \Gamma^\*$
\begin{equation\*}
 \sum\_{ \mathbf{n}\in \Gamma^\* }\iiint \_{\Omega^\* +\mathbf{n}} e^{i \mathbf{k}\cdot \mathbf{x}} \hat{u}(\mathbf{k})\,d^n\mathbf{k},
\end{equation\*}
then change variable $\mathbf{k}=\mathbf{k}\_{\textsf{new}}+\mathbf{n}$
\begin{equation\*}
\iiint \_{\Omega^\* } e^{i (\mathbf{k}+\mathbf{n})\cdot \mathbf{x}}
\Bigl( \underbrace{\sum\_{ \mathbf{n}\in \Gamma^\* } e^{i \mathbf{n}\cdot \mathbf{x}} \hat{u}(\mathbf{k}+\mathbf{n})}\_{=U(\mathbf{k},\mathbf{x})}\Bigr)d^n\mathbf{k},
\end{equation\*}
we observe that $U(\mathbf{k},\mathbf{x})$ is quasiperiodic with quasimomentum $\mathbf{k}$.

In advanced Real Analysis it would be a decomposition of our Hilbert space $\mathsf{H}=L^2(\mathbb{R}^n)$ into *direct integral of Hilbert spaces* $\mathsf{H}(\mathbf{k})$ of such functions, and our operator is acting in each of those spaces separately, with a spectrum $\sigma (L(\mathbf{k}))=\\{E\_n (\mathbf{k}): n=1,2,\ldots\\}$. This  implies that $L$ has a *band spectrum*: it  consists of *spectral bands* $\sigma\_n:=[\min \_{k\in \Omega^\*} E\_n(k) ,\max \_{k\in \Omega^\*} E\_n(k)]$:
\begin{equation\*}
\sigma(L) =\bigcup_{n=1}^\infty \sigma\_n;
\end{equation\*}
these spectral bands can overlap. On can prove that   $E\_n (\mathbf{k})$ really depend on $\mathbf{k}$ and are not taking the same value on some set of *non–zero measure* (another notion from Real Analysis) which implies that the spectrum $\sigma(L)$ is continuos.

_________

[$\Leftarrow$](./S13.3.html)&nbsp;&nbsp;[$\Uparrow$](./contents.html)&nbsp;&nbsp;[$\Rightarrow$](./S13.5.html)

