<link href="../markdown.css" rel="stylesheet"></link>

<title>2.1. First order PDEs</title>

<script type="text/javascript" src="https://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS_HTML">
    MathJax.Hub.Config({
        tex2jax: {
            inlineMath: [ ['$','$'], ["\\(","\\)"] ],
            displayMath: [ ['$$','$$'], ["\\[","\\]"] ],},
        TeX: {equationNumbers: {
            autoNumber: "AMS"
          },Augment: {  Definitions: {
           macros: {
             overbracket:  ['UnderOver','23B4',1],
             underbracket: ['UnderOver','23B5',1],
           }
         }}},
    });
</script>

$\renewcommand{\Re}{\operatorname{Re}}$
$\renewcommand{\Im}{\operatorname{Im}}$
$\newcommand{\erf}{\operatorname{erf}}$
$\newcommand{\dag}{\dagger}$
$\newcommand{\const}{\mathrm{const}}$
$\newcommand{\arcsinh}{\operatorname{arcsinh}}$


#Chapter 2. $1$-dimensional waves

In this Chapter we first consider first order PDE and then move to $1$-dimensional wave equation which we analyze by the *method of characteristics*.



##2.1. First order PDEs

-----

> 1.  [Introduction](#sect-2.1.1)
> 2.  [Constant coefficients](#sect-2.1.2)
> 3.  [Variable coefficients](#sect-2.1.3)
> 4.  [Right-hand expression](#sect-2.1.4)
> 5.  [Linear and semilinear equations](#sect-2.1.5)
> 6.  [Quasilinear equations](#sect-2.1.6)
> 7.  [IBVP](#sect-2.1.7)
> 8.  [Problems](./S2.1.P.html)


###<span id="sect-2.1.1"></span>Introduction

Consider PDE
\begin{equation} au\_t+bu\_x=0.
\label{eq-2.1.1}
\end{equation}
Note that the left-hand expression is a *derivative of $u$ along vector field $\ell=(a,b)$*. Consider an *integral lines* of this vector field:
\begin{equation}
\frac{dt}{a}=\frac{dx}{b}.
\label{eq-2.1.2}
\end{equation}

**<span id="remark-2.1.1"></span>Remark 1.**

a. Recall from ODE cours that an *integral line* of the vector field is a line, tangent to it in each point.

b. Often it is called *directional derivative* but also often then $\ell$ is *normalized*, replaced by the unit vector of the same direction $\ell^0=\ell/|\ell|$.


###<span id="sect-2.1.2"></span>Constant coefficients

If $a$ and $b$ are constant then integral curves are just straight lines
$t/a -x/b=C$ where $C$ is a constant along integral curves and it labels them (at least as long as we consider the whole plane $(x,t)$). Therefore $u$ depends only on $C$:
\begin{equation}
u= \phi \bigl( \frac{t}{a}-\frac{x}{b}\bigr)
\label{eq-2.1.3}
\end{equation}
where  $\phi$ is an arbitrary function.

This is a *general solution* of our equation.

Consider initial value condition $u|\_{t=0}=f(x)$. It allows us define
$\phi$: $\phi(-x/b)=f(x)\implies \phi (x)= f(-bx)$. Plugging in $u$ we get
\begin{equation}
u=f\bigl( x-ct\bigr)\qquad\text{with  } c=b/a.
\label{eq-2.1.4}
\end{equation}
It is a solution of IVP
\begin{equation}
\left\\{\begin{aligned}
&au\_t+bu\_x=0,\\\\
&u(x,0)=f(x).
\end{aligned} \\right.
\label{eq-2.1.5}
\end{equation}
Obviously we need to assume that $a\ne 0$.

If $a=1$ we can rewrite general solution in the form $u(x,t)=\phi\_1 (x-bt)$ where $\phi\_1(x)=\phi(-x/b)$ is another arbitrary function.

**<span id="definition-2.1.1"></span>Definition 1.**
Solutions $u=\chi(x-ct)$ are *running waves* where $c$ is a *propagation speed*.

###<span id="sect-2.1.3"></span>Variable coefficients

If $a$ and/or $b$ are not constant these integral lines are curves.

**<span id="example-2.1.1"></span>Example 1.**
Consider equation $u\_t+tu\_x=0$. Then equation of the integral curve is $\frac{dt}{1}=\frac{dx}{t}$ or equivalently $tdt-dx=0$ which solves as $x-\frac{1}{2}t^2=C$ and therefore $u=\phi (x-\frac{1}{2}t^2)$ is a general solution to this equation.

One can see easily that $u=f(x-\frac{1}{2}t^2)$ is a solution of IVP.

**<span id="example-2.1.2"></span>Example 2.** Consider the same equation but let us consider IVP as $x=0$: $u(0,t)=g(t)$. However it is not a good problem: first, some integral curves intersect line $x=0$ more than once and if in different points of intersection of the same curve initial values are different we get a contradiction (therefore problem is not solvable for $g$ which are not even functions).

On the other hand, if we consider even function $g$ (or equivalently
impose initial condition only for $t>0$) then $u$ is not defined on
the curves which are not intersecting $x=0$ (which means that $u$ is
not defined for $x> \frac{1}{2}t^2$.)

In this example both *solvability* and *unicity* are broken.


###<span id="sect-2.1.4"></span>Right-hand expression

Consider the same equation albeit with the right-hand expression
\begin{equation}
au\_t+bu\_x=f.
\label{eq-2.1.6}
\end{equation}
Then as $\frac{dt}{a}=\frac{dx}{b}$ we have
$du = u\_t dt + u\_xdx = (au\_t+bu\_x) \frac{dt}{a}=f \frac{dt}{a}$ and therefore we expand our ordinary equation (\ref{eq-2.1.2}) to
\begin{equation}
\frac{dt}{a}=\frac{dx}{b}=\frac{du}{f}.
\label{eq-2.1.7}
\end{equation}

**<span id="example-2.1.3"></span>Example 3.** Consider problem $u\_t+u\_x=x$. Then
$\frac{dx}{1}=\frac{dt}{1}=\frac{du}{x}$. Then $x-t=C$ and $u-\frac{1}{2}x^2=D$ and we get $u-\frac{1}{2}x^2 = \phi (x-t)$ as relation between $C$ and $D$ both of which are constants along integral curves. Here $\phi$ is an arbitrary function. So $u=\frac{1}{2}x^2 + \phi (x-t)$ is a general solution. Imposing Imposing initial condition $u|\_{t=0}=0$ (sure, we could impose another condition) we have $\phi(x)=-\frac{1}{2}x^2$ and plugging into $u$ we get
$u(x,t)=\frac{1}{2}x^2-\frac{1}{2}(x-t)^2= xt - \frac{1}{2}t^2$.


**<span id="example-2.1.4"></span>Example 4.** Consider $u\_t+ xu\_x = x t$. Then $\frac{dt}{1}=\frac{dx}{x}=\frac{du}{xt}$. Solving the first equation $t-\ln x=-\ln C\implies x =Ce^t$ we get integral curves.
Now we have
\begin{equation\*}
\frac{du}{xt}=dt \implies du= x t dt= Cte^t dt \implies u=C(t-1)e^t +D =
x(t-1)+D
\end{equation\*}
where $D$ must be constant along integral curves and therefore
$D=\phi (xe^{-t})$ with an arbitrary function $\phi$. So
$u=x(t-1)+\phi (xe^{-t})$ is a general solution of this equation.

Imposing initial condition $u|\_{t=0}=0$ (sure, we could impose another condition) we have $\phi(x)=x$ and then  $u=x(t-1 +e^{-t})$.


###<span id="sect-2.1.5"></span>Linear and semilinear equations

**<span id="definition-2.1.2"></span>Definition 2.** If $a=a(x,t)$ and $b=b(x,t)$ equation is *semilinear*.

In this case we first define integral curves which do not depend on $u$ and then find $u$ as a solution of ODE along these curves.

**<span id="definition-2.1.3"></span>Definition 3.**
Furthermore if $f$ is a linear function of $u$: $f=c(x,t)u + g(x,t)$ original equation is *linear*.


In this case the last ODE is also linear.

**<span id="example-2.1.5"></span>Example 5.** Consider $u\_t+ xu\_x = u$. Then $\frac{dt}{1}=\frac{dx}{x}=\frac{du}{u}$. Solving the first
equation $t-\ln x=-\ln C\implies x =Ce^t$ we get integral curves.
Now we have
\begin{equation\*}
\frac{du}{u}=dt \implies \ln u= t+\ln D \implies u=De^t=\phi (xe^{-t})e^t
\end{equation\*}
which is a general solution of this equation.

Imposing initial condition $u|\_{t=0}=x^2$ (sure, we could impose another condition) we have $\phi(x)= x^2$ and then  $u=x^2 e^{-t}$.


**<span id="example-2.1.6"></span>Example 6.** Consider $u\_t+ xu\_x = -u^2$. Then $\frac{dt}{1}=\frac{dx}{x}=-\frac{du}{u^2}$. Solving the first equation $x =Ce^t$ we get integral curves.
Now we have
\begin{equation\*}
-\frac{du}{u^2}=dt \implies u^{-1}= t+ D \implies u=(t+ \phi(xe^{-t}))^{-1}.
\end{equation\*}
which is a general solution of this equation.


###<span id="sect-2.1.6"></span>Quasilinear equations

**<span id="definition-2.1.4"></span>Definition 4.** If $a$ and/or $b$ depend on $u$ this is *quasininear* equation.


For such equations integral curves depend on the solution which can lead
to breaking of solution.

**<span id="example-2.1.7"></span>Example 7.**
Consider Burgers equation $u\_t+uu\_x=0$ (which is an extremely simplified model of gas dynamics. ) We have $\frac{dt}{1}=\frac{dx}{u}=\frac{du}{0}$ and therefore $u=\const$ along integral curves and therefore integral curves are $x-ut=C$.

Consider initial problem $u(x,0)=f(x)$. We take initial point $(y,0)$, find here $u=f(y)$, then $x-f(y)t =y$ (think why?) and we get $u=f(y)$ where $y=y(x,t)$ is a solution of equation $x=f(y)t +y$.

The trouble is that we can define $y$ for all $x$ only if
$\frac{\partial }{\partial y}\bigl(f(y)t +y\bigr)$ does not vanish. So,
$f'(y)t +1\ne 0$.

This is possible for all $t\>0$ if and only if $f'(y)\ge 0$ i.e. $f$ is a monotone non-decreasing function.

So, classical solution breaks if $f$ is not a monotone non-decreasing function. A proper understanding of the *global solution* for such equation goes well beyond our course.


**<span id="example-2.1.8"></span>Example 8.**
Traffic flow is considered in [Appendix](./S2.1.A.html)

###<span id="sect-2.1.7"></span>IBVP

Consider IBVP (initial-boundary value problem) for constant coefficient equation
\begin{equation}
\left\\{\begin{aligned}
&u\_t +cu\_x=0, \qquad &&x\>0,\ t\>0,\\\\
&u|\_{t=0}= f(x) \qquad &&x\>0.
\end{aligned}\right.
\label{eq-2.1.8}
\end{equation}

The general solution is $u=\phi(x-ct)$ and plugging into initial data
we get $\phi(x)=f(x)$ (as $x\>0$).

So, $u(x,t)= f(x-ct)$. Done!–Not so fast. $f$ is defined only for
$x >0$ so $u$ is defined for $x-ct >0$ (or $x >ct$). It covers
the whole quadrant if $c\le 0$ (so waves run to the left) and only in
this case we are done.

If $c\>0$ (waves run to the right) $u$ is not defined as $x<  ct$
and to define it here we need a *boundary condition* at $x=0$. So we
get IBVP (initial-boundary value problem)
\begin{equation}
\left\\{\begin{aligned}
&u\_t +cu\_x=0, \qquad &&x>0, t>0,\\\\
&u|\_{t=0}= f(x) \qquad &&x>0,\\\\
&u|\_{x=0}=g(t) \qquad &&t >0.
\end{aligned}\\right.
\label{eq-2.1.9}
\end{equation}
Then we get $\phi(-ct)=g(t)$ as $t>0$ which implies $\phi(x)=g(-\frac{1}{c}x)$ as $x<0$ and then $u(x,t)=g(-\frac{1}{c}(x-ct))=g(t-\frac{1}{c}x)$ as $x< ct$.

So solution is
\begin{equation}
u=\left\\{\begin{aligned}
&f(x-ct)\qquad &&x> c t,\\\\
&g(t-\frac{1}{c}x)\qquad && x < ct.
\end{aligned}\right.
\label{eq-2.1.10}
\end{equation}




______

[$\Leftarrow$](../Chapter1/S1.X.html)&nbsp;&nbsp;[$\Uparrow$](../contents.html)&nbsp;&nbsp;[$\Downarrow$](./S2.1.A.html)&nbsp;&nbsp;[$\downarrow$](./S2.1.P.html)&nbsp;&nbsp;[$\Rightarrow$](./S2.2.html)
